pub enum Command {
BuildSquad(BuildSquad),
SelectBattlegroup(SelectBattlegroup),
Unknown(Unknown),
}Expand description
Wrapper for one of many Company of Heroes 3 player commands parsed from a replay file. For details on the specifics of a given command, see the specific enum variants.
Commands are collected during tick parsing and then associated with the Player instance that
sent them. To access, see Player::commands.
Variants